Config class
Constructors
- Config()
Properties
- figureAlpha ↔ MinMaxValue
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashKey ↔ String
-
getter/setter pair
- hue ↔ MinMaxValue
-
getter/setter pair
- light ↔ LightValue
-
getter/setter pair
- lightness ↔ MinMaxValue
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saturation ↔ MinMaxValue
-
getter/setter pair
- shift ↔ MinMaxValue
-
getter/setter pair
- variation ↔ VariationValue
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited